
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Action::GenerateFile::named_conf - action to generate named.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::named_conf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ( $opt, $zone );

    print $fh "\noptions\n{\n";
    foreach $opt ( sort keys %{ $self->{options} } )
    {
        if ( ref( $self->{options}->{$opt} ) eq 'ARRAY' )
        {
            print $fh "\t$opt\n\t{\n\t\t";
            print $fh join( ";\n\t\t", @{ $self->{options}->{$opt} } );
            print $fh ";\n\t};\n\n";
            next;
        }

        print $fh "\t$opt\t$self->{options}->{$opt};\n\n";
    }
    print $fh "};\n\n";

    foreach $zone ( sort keys %{ $self->{zones} } )
    {
        print $fh "zone \"$zone\"\n{\n";
        foreach $opt ( sort keys %{ $self->{zones}->{$zone} } )
        {
            print $fh "\t$opt\t$self->{zones}->{$zone}->{$opt};\n";
        }
        print $fh "};\n\n";
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::named_conf - generate named.conf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::named_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::named_conf->new(
			'name'		=> '/etc/named.conf',
			'options'	=> { ... },
			'zones'		=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::named_conf> module provides a B<PSGConf>
action class for generating the F<named.conf> file.

The B<PSGConf::Action::GenerateFile::named_conf> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the F<named.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::named_conf> class supports the following
attributes:

=over 4

=item I<options>

A hash of options and their values.

=item I<zones>

A hash mapping zones to a hash of the options for that zone.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

