
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Action::GenerateFile::pam_conf - action to generate /etc/pam.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::pam_conf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ( $pam_svc, $entry );

    foreach $pam_svc ( sort keys %{ $self->{pam_conf} } )
    {
        print $fh "\n# PAM configuration for $pam_svc\n";
        foreach $entry ( @{ $self->{pam_conf}->{$pam_svc} } )
        {
            print $fh "$pam_svc\t$entry\n";
        }
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::pam_conf - generate /etc/pam.conf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::pam_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::pam_conf->new(
			'name'		=> '/etc/pam.conf',
			'pam_conf'	=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::pam_conf> module provides a B<PSGConf>
action class for generating the F</etc/pam.conf> file.

The B<PSGConf::Action::GenerateFile::pam_conf> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the F<pam.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::pam_conf> class supports the following
attributes:

=over 4

=item I<pam_conf>

A hash mapping PAM service names to a list of entries for that service
name.

=back

=head1 BUGS

The I<pam_conf> attribute should be restructured to split up the fields
of the individual entries, rather than encoding them as a single
string.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

