
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  sendmail_cf.pm - psgconf action to generate sendmail .cf files
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::sendmail_cf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate() method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ( $mc_action, $infile );
    my ( $line, $cmd, $infh );

    return 0
      if ( !exists( $self->{user} )
        || !exists( $self->{m4_command} )
        || !exists( $self->{sendmail_m4_dir} ) );

    $mc_action = $psgconf->get_action( $self->{mc_file} );
    $infile    = (
        ( defined($mc_action) && $mc_action->changed() )
        ? $mc_action->{tmpfile}
        : $self->{mc_file}
    );

    $cmd =
"LOGNAME=$self->{user} $self->{m4_command} -D_CF_DIR_=$self->{sendmail_m4_dir}/ $self->{sendmail_m4_dir}/m4/cf.m4";
    if ( !open( $infh, "$cmd $infile |" ) )
    {
        warn "\t!!! m4 failed: $!\n";
        return -1;
    }

    while ( $line = <$infh> )
    {
        ### strip out date so we don't find a difference every time
        $line =~ s|^(##### built by \S+) on .*($)|$1$2|;

        ### skip line containing current directory
        next
          if ( $line =~ m|^##### in /| );

        print $fh $line;
    }

    close($infh);
    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::sendmail_cf - generate sendmail.cf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::sendmail_cf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::sendmail_cf->new(
			'name'		=> '/etc/mail/sendmail.cf',
			'mc_file'	=> '/etc/mail/sendmail.mc',
			'm4_command'	=> '/usr/local/bin/m4',
			'sendmail_m4_dir' => '/usr/local/share/sendmail',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::sendmail_cf> module provides a
B<PSGConf> action class for generating a C<sendmail> F<.cf> file from
a F<.mc> file.

The B<PSGConf::Action::GenerateFile::sendmail_cf> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F<sendmail.cf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::sendmail_cf> class supports the following
attributes:

=over 4

=item I<m4_command>

The path to the C<m4> command.

=item I<mc_file>

The path to the F<.mc> source file.

=item I<sendmail_m4_dir>

The path to the C<sendmail> macro directory.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


