
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  syslog_conf.pm - psgconf action to generate /etc/syslog.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::syslog_conf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate() method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ($target);

    foreach $target ( sort keys %{ $self->{syslog} } )
    {
        print $fh $self->{syslog}->{$target} . "\t$target\n";
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::syslog_conf - generate /etc/syslog.conf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::syslog_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::syslog_conf->new(
			'name'		=> '/etc/syslog.conf',
			'syslog'	=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::syslog_conf> module provides a
B<PSGConf> action class for generating the F</etc/syslog.conf> file.

The B<PSGConf::Action::GenerateFile::syslog_conf> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F</etc/syslog.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::syslog_conf> class supports the following
attributes:

=over 4

=item I<syslog>

A hash mapping log targets to the facilities/priorities that should be
sent to that target.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


